# coding: utf-8

"""
    OneLogin API Python SDK

    Official Python SDK for the OneLogin API
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, ClassVar, List
from pydantic import BaseModel, Field, StrictBool, StrictStr, field_validator

class EnforcementPointResourcesInner(BaseModel):
    """
    EnforcementPointResourcesInner
    """
    path: Optional[StrictStr] = None
    is_path_regex: Optional[StrictBool] = None
    require_auth: Optional[StrictBool] = None
    permission: Optional[StrictStr] = None
    conditions: Optional[StrictStr] = Field(None, description="required if permission == \"conditions\"")
    
    # Define properties as a class variable
    _properties: ClassVar[List[str]] = ["path", "is_path_regex", "require_auth", "permission", "conditions"]

    @field_validator('permission')
    @classmethod
    def permission_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('allow', 'deny', 'conditions'):
            raise ValueError("must be one of enum values ('allow', 'deny', 'conditions')")
        return value

    """Pydantic configuration"""
    model_config = {
        "validate_by_name": True,
        "validate_by_alias": True,
        "validate_assignment": True
    }

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> EnforcementPointResourcesInner:
        """Create an instance of EnforcementPointResourcesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.model_dump(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if is_path_regex (nullable) is None
        # and __fields_set__ contains the field
        if self.is_path_regex is None and "is_path_regex" in self.__fields_set__:
            _dict['is_path_regex'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> EnforcementPointResourcesInner:
        """Create an instance of EnforcementPointResourcesInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return EnforcementPointResourcesInner.model_validate(obj)

        _obj = EnforcementPointResourcesInner.model_validate({
            "path": obj.get("path"),
            "is_path_regex": obj.get("is_path_regex"),
            "require_auth": obj.get("require_auth"),
            "permission": obj.get("permission"),
            "conditions": obj.get("conditions")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API Python SDK

    Official Python SDK for the OneLogin API
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from pydantic import BaseModel, conlist
from onelogin.models.remove_user_role_request_role_id_array_inner import RemoveUserRoleRequestRoleIdArrayInner

class RemoveUserRoleRequest(BaseModel):
    """
    RemoveUserRoleRequest
    """
    role_id_array: conlist(RemoveUserRoleRequestRoleIdArrayInner) = ...
    __properties = ["role_id_array"]

    """Pydantic configuration"""
    model_config = {
        "validate_by_name": True,
        "validate_by_alias": True,
        "validate_assignment": True
    }

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RemoveUserRoleRequest:
        """Create an instance of RemoveUserRoleRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.model_dump(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in role_id_array (list)
        _items = []
        if self.role_id_array:
            for _item in self.role_id_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['role_id_array'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RemoveUserRoleRequest:
        """Create an instance of RemoveUserRoleRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RemoveUserRoleRequest.model_validate(obj)

        _obj = RemoveUserRoleRequest.model_validate({
            "role_id_array": [RemoveUserRoleRequestRoleIdArrayInner.from_dict(_item) for _item in obj.get("role_id_array")] if obj.get("role_id_array") is not None else None
        })
        return _obj




# coding: utf-8

"""
    OneLogin API Python SDK

    Official Python SDK for the OneLogin API
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr, conlist
from onelogin.models.scope import Scope

class ClientAppFull(BaseModel):
    """
    ClientAppFull
    """
    scopes: Optional[conlist(Scope)] = Field(None, description="List of All Scopes assigned to a client app")
    app_id: Optional[StrictInt] = Field(None, description="Unique Client App ID")
    name: Optional[StrictStr] = Field(None, description="Name of client app")
    api_auth_id: Optional[StrictInt] = None
    __properties = ["scopes", "app_id", "name", "api_auth_id"]

    """Pydantic configuration"""
    model_config = {
        "validate_by_name": True,
        "validate_by_alias": True,
        "validate_assignment": True
    }

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ClientAppFull:
        """Create an instance of ClientAppFull from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.model_dump(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in scopes (list)
        _items = []
        if self.scopes:
            for _item in self.scopes:
                if _item:
                    _items.append(_item.to_dict())
            _dict['scopes'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ClientAppFull:
        """Create an instance of ClientAppFull from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ClientAppFull.model_validate(obj)

        _obj = ClientAppFull.model_validate({
            "scopes": [Scope.from_dict(_item) for _item in obj.get("scopes")] if obj.get("scopes") is not None else None,
            "app_id": obj.get("app_id"),
            "name": obj.get("name"),
            "api_auth_id": obj.get("api_auth_id")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API Python SDK

    Official Python SDK for the OneLogin API
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, ValidationError, conlist, field_validator
from onelogin.models.action_obj import ActionObj
from onelogin.models.condition import Condition

class Mapping(BaseModel):
    """
    Mapping
    """
    id: Optional[StrictInt] = None
    name: StrictStr = Field(..., description="The name of the mapping.")
    enabled: StrictBool = Field(..., description="Indicates if the mapping is enabled or not.")
    match: StrictStr = Field(..., description="Indicates how conditions should be matched.")
    position: Optional[StrictInt] = Field(None, description="Indicates the order of the mapping. When `null` this will default to last position.")
    conditions: conlist(Condition) = Field(..., description="An array of conditions that the user must meet in order for the mapping to be applied.")
    actions: conlist(ActionObj) = Field(..., description="An array of actions that will be applied to the users that are matched by the conditions.")
    __properties = ["id", "name", "enabled", "match", "position", "conditions", "actions"]

    @field_validator('match')
    @classmethod
    def match_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('all', 'any'):
            raise ValueError("must be one of enum values ('all', 'any')")
        return value

    """Pydantic configuration"""
    model_config = {
        "validate_by_name": True,
        "validate_by_alias": True,
        "validate_assignment": True
    }

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Mapping:
        """Create an instance of Mapping from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.model_dump(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in conditions (list)
        _items = []
        if self.conditions:
            for _item in self.conditions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['conditions'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in actions (list)
        _items = []
        if self.actions:
            for _item in self.actions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['actions'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Mapping:
        """Create an instance of Mapping from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Mapping.model_validate(obj)

        _data = {
            "id": obj.get("id"),
            "name": obj.get("name"),
            "enabled": obj.get("enabled"),
            "match": obj.get("match"),
            "position": obj.get("position"),
            "conditions": [Condition.from_dict(_item) for _item in obj.get("conditions")] if obj.get("conditions") is not None else None,
            "actions": [ActionObj.from_dict(_item) for _item in obj.get("actions")] if obj.get("actions") is not None else None
        }

        # Create Mapping can return a partial payload (e.g., {"id": ...}).
        # Validate strictly, but fall back to model_construct for the narrow
        # id-only case so successful creates do not raise.
        try:
            return Mapping.model_validate(_data)
        except ValidationError:
            if set(obj.keys()) == {"id"} and obj.get("id") is not None:
                return Mapping.model_construct(**_data)
            raise



# coding: utf-8

"""
    OneLogin API Python SDK

    Official Python SDK for the OneLogin API
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, conlist

class UpdateClientAppRequest(BaseModel):
    """
    UpdateClientAppRequest
    """
    scopes: Optional[conlist(StrictInt)] = Field(None, description="An array of Scope IDs the scopes the app can request")
    __properties = ["scopes"]

    """Pydantic configuration"""
    model_config = {
        "validate_by_name": True,
        "validate_by_alias": True,
        "validate_assignment": True
    }

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UpdateClientAppRequest:
        """Create an instance of UpdateClientAppRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.model_dump(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UpdateClientAppRequest:
        """Create an instance of UpdateClientAppRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UpdateClientAppRequest.model_validate(obj)

        _obj = UpdateClientAppRequest.model_validate({
            "scopes": obj.get("scopes")
        })
        return _obj




# coding: utf-8

"""
SAML2 Authentication Module

This module provides compatibility for users expecting to import
OneLogin_Saml2_Auth from onelogin.saml2.auth. However, OneLogin_Saml2_Auth is
actually provided by the 'python3-saml' package, not this onelogin package.

This onelogin package is for OneLogin API management, while python3-saml is
for SAML2 authentication integration.
"""



# coding: utf-8

"""
    OneLogin API Python SDK

    Official Python SDK for the OneLogin API
"""


from __future__ import annotations
import json
import re  # noqa: F401
from aenum import Enum





class AuthMethod(int, Enum):
    """
    An ID indicating the type of app:   - 0: Password   - 1: OpenId   - 2: SAML   - 3: API   - 4: Google   - 6: Forms Based App   - 7: WSFED   - 8: OpenId Connect
    """

    """
    allowed enum values
    """
    NUMBER_0 = 0
    NUMBER_1 = 1
    NUMBER_2 = 2
    NUMBER_3 = 3
    NUMBER_4 = 4
    NUMBER_5 = 5
    NUMBER_6 = 6
    NUMBER_7 = 7
    NUMBER_8 = 8

    @classmethod
    def from_json(cls, json_str: str) -> AuthMethod:
        """Create an instance of AuthMethod from a JSON string"""
        return AuthMethod(json.loads(json_str))






# coding: utf-8

"""
    OneLogin API Python SDK

    Official Python SDK for the OneLogin API
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from pydantic import BaseModel, Field, StrictStr, conlist, field_validator

class PrivilegePrivilegeStatementInner(BaseModel):
    """
    PrivilegePrivilegeStatementInner
    """
    effect: StrictStr = Field(..., alias="Effect", description="Set to “Allow.” By default, all actions are denied, this Statement allows the listed actions to be executed.")
    action: conlist(StrictStr) = Field(..., alias="Action", description="An array of strings that represent actions within OneLogin. Actions are prefixed with the class of object they are related to and followed by a specific action for the given class. e.g. users:List, where the class is users and the specific action is List. Don’t mix classes within an Action array. To create a privilege that includes multiple different classes, create multiple statements. A wildcard * that includes all actions is supported. Use wildcards to create a Super User privilege.")
    scope: conlist(StrictStr) = Field(..., alias="Scope", description="Target the privileged action against specific resources with the scope. The scope pattern is the class of object used by the Action, followed by an ID that represents a resource in OneLogin. e.g. apps/1234, where apps is the class and 1234 is the ID of an app. The wildcard * is supported and indicates that all resources of the class type declared, in the Action, are in scope. The Action and Scope classes must match. However, there is an exception, a scope of roles/{role_id} can be combined with Actions on the user or app class. The exception allows you to target groups of users or apps with specific actions.")
    __properties = ["Effect", "Action", "Scope"]

    @field_validator('action')
    @classmethod
    def action_validate_enum(cls, value):
        """Validates the enum"""
        for i in value:
            if i not in ('apps:Create', 'apps:Delete', 'apps:List', 'apps:Get', 'apps:Update', 'apps:ManageConnectors', 'apps:ManageRoles', 'apps:ManageTabs', 'apps:ManageUsers', 'apps:ReapplyMappings', 'users:Create', 'users:Delete', 'users:List', 'users:Get', 'users:Update', 'users:AssumeUser', 'users:ManageApps', 'users:Unlock', 'users:GenerateTempMfaToken', 'users:ResetPassword', 'users:ReapplyMappings', 'users:ManageLicense', 'users:Invite', 'users:ManageRoles', 'roles:Create', 'roles:Get', 'roles:List', 'roles:Update', 'roles:Delete', 'roles:ManageUsers', 'roles:ManageApps', 'reports:Create', 'reports:Get', 'reports:List', 'reports:Update', 'reports:Delete', 'reports:Clone', 'events:Get', 'events:List', 'groups:Create', 'groups:Get', 'groups:List', 'groups:Update', 'groups:Delete', 'policies:Create', 'policies:Get', 'policies:List', 'policies:Update', 'policies:Delete', 'policies:SetDefault'):
                raise ValueError("each list item must be one of ('apps:Create', 'apps:Delete', 'apps:List', 'apps:Get', 'apps:Update', 'apps:ManageConnectors', 'apps:ManageRoles', 'apps:ManageTabs', 'apps:ManageUsers', 'apps:ReapplyMappings', 'users:Create', 'users:Delete', 'users:List', 'users:Get', 'users:Update', 'users:AssumeUser', 'users:ManageApps', 'users:Unlock', 'users:GenerateTempMfaToken', 'users:ResetPassword', 'users:ReapplyMappings', 'users:ManageLicense', 'users:Invite', 'users:ManageRoles', 'roles:Create', 'roles:Get', 'roles:List', 'roles:Update', 'roles:Delete', 'roles:ManageUsers', 'roles:ManageApps', 'reports:Create', 'reports:Get', 'reports:List', 'reports:Update', 'reports:Delete', 'reports:Clone', 'events:Get', 'events:List', 'groups:Create', 'groups:Get', 'groups:List', 'groups:Update', 'groups:Delete', 'policies:Create', 'policies:Get', 'policies:List', 'policies:Update', 'policies:Delete', 'policies:SetDefault')")
        return value

    """Pydantic configuration"""
    model_config = {
        "validate_by_name": True,
        "validate_by_alias": True,
        "validate_assignment": True
    }

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PrivilegePrivilegeStatementInner:
        """Create an instance of PrivilegePrivilegeStatementInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.model_dump(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PrivilegePrivilegeStatementInner:
        """Create an instance of PrivilegePrivilegeStatementInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PrivilegePrivilegeStatementInner.model_validate(obj)

        _obj = PrivilegePrivilegeStatementInner.model_validate({
            "effect": obj.get("Effect"),
            "action": obj.get("Action"),
            "scope": obj.get("Scope")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API Python SDK

    Official Python SDK for the OneLogin API
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr, constr, field_validator
from onelogin.models.message_template_template import MessageTemplateTemplate

class MessageTemplate(BaseModel):
    """
    MessageTemplate
    """
    id: Optional[StrictInt] = None
    account_id: Optional[StrictInt] = None
    type: StrictStr = Field(..., description="Template type that describes the source (sms, voice, email) and purpose (registration, invite, etc)")
    locale: constr(strict=True) = Field(..., description="The 2 character language locale for the template. e.g. en = English, es = Spanish")
    template: MessageTemplateTemplate = ...
    template_class: Optional[StrictStr] = None
    updated_at: Optional[StrictStr] = Field(None, description="Last time template was updated")
    brand_id: Optional[StrictInt] = Field(None, description="brand id number")
    __properties = ["id", "account_id", "type", "locale", "template", "template_class", "updated_at", "brand_id"]

    @field_validator('type')
    @classmethod
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('email_forgot_password', 'email_code_registration', 'email_code_login_verification', 'email_code_app_verification', 'email_code_pw_reset_verification', 'email_magiclink_registration', 'email_magiclink_login_verification', 'email_magiclink_app_verification', 'email_magiclink_pw_reset_verification', 'sms_registration', 'sms_login_verification', 'sms_app_verification', 'sms_pw_reset_verification'):
            raise ValueError("must be one of enum values ('email_forgot_password', 'email_code_registration', 'email_code_login_verification', 'email_code_app_verification', 'email_code_pw_reset_verification', 'email_magiclink_registration', 'email_magiclink_login_verification', 'email_magiclink_app_verification', 'email_magiclink_pw_reset_verification', 'sms_registration', 'sms_login_verification', 'sms_app_verification', 'sms_pw_reset_verification')")
        return value

    @field_validator('locale')
    @classmethod
    def locale_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[a-z]{2}$", value):
            raise ValueError(r"must validate the regular expression /^[a-z]{2}$/")
        return value

    """Pydantic configuration"""
    model_config = {
        "validate_by_name": True,
        "validate_by_alias": True,
        "validate_assignment": True
    }

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MessageTemplate:
        """Create an instance of MessageTemplate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.model_dump(by_alias=True,
                          exclude={
                            "id",
                            "account_id",
                            "template_class",
                            "updated_at",
                            "brand_id",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of template
        if self.template:
            _dict['template'] = self.template.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MessageTemplate:
        """Create an instance of MessageTemplate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return MessageTemplate.model_validate(obj)

        _obj = MessageTemplate.model_validate({
            "id": obj.get("id"),
            "account_id": obj.get("account_id"),
            "type": obj.get("type"),
            "locale": obj.get("locale"),
            "template": MessageTemplateTemplate.from_dict(obj.get("template")) if obj.get("template") is not None else None,
            "template_class": obj.get("template_class"),
            "updated_at": obj.get("updated_at"),
            "brand_id": obj.get("brand_id")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API Python SDK

    Official Python SDK for the OneLogin API
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, conlist
from onelogin.models.error import Error
from onelogin.models.get_role_by_name200_response_data_inner import GetRoleByName200ResponseDataInner
from onelogin.models.get_role_by_name200_response_pagination import GetRoleByName200ResponsePagination

class GetRoleByName200Response(BaseModel):
    """
    GetRoleByName200Response
    """
    status: Optional[Error] = None
    pagination: Optional[GetRoleByName200ResponsePagination] = None
    data: Optional[conlist(GetRoleByName200ResponseDataInner)] = None
    __properties = ["status", "pagination", "data"]

    """Pydantic configuration"""
    model_config = {
        "validate_by_name": True,
        "validate_by_alias": True,
        "validate_assignment": True
    }

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GetRoleByName200Response:
        """Create an instance of GetRoleByName200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.model_dump(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of status
        if self.status:
            _dict['status'] = self.status.to_dict()
        # override the default output from pydantic by calling `to_dict()` of pagination
        if self.pagination:
            _dict['pagination'] = self.pagination.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in data (list)
        _items = []
        if self.data:
            for _item in self.data:
                if _item:
                    _items.append(_item.to_dict())
            _dict['data'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GetRoleByName200Response:
        """Create an instance of GetRoleByName200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return GetRoleByName200Response.model_validate(obj)

        _obj = GetRoleByName200Response.model_validate({
            "status": Error.from_dict(obj.get("status")) if obj.get("status") is not None else None,
            "pagination": GetRoleByName200ResponsePagination.from_dict(obj.get("pagination")) if obj.get("pagination") is not None else None,
            "data": [GetRoleByName200ResponseDataInner.from_dict(_item) for _item in obj.get("data")] if obj.get("data") is not None else None
        })
        return _obj




# coding: utf-8

"""
    OneLogin API Python SDK

    Official Python SDK for the OneLogin API
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist

class TokenClaim(BaseModel):
    """
    TokenClaim
    """
    id: Optional[StrictInt] = Field(None, description="The unique ID of the claim.")
    label: Optional[StrictStr] = Field(None, description="The UI label for the claims.")
    user_attribute_mappings: Optional[StrictStr] = Field(None, description="A user attribute to map values from.")
    user_attribute_macros: Optional[StrictStr] = Field(None, description="When `user_attribute_mappings` is set to `_macro_` this macro will be used to assign the claims value.")
    attribute_transformations: Optional[StrictStr] = Field(None, description="The type of transformation to perform on multi valued attributes.")
    skip_if_blank: Optional[StrictBool] = Field(None, description="not used")
    values: Optional[conlist(StrictStr)] = Field(None, description="Relates to Rules/Entitlements. Not supported yet.")
    default_values: Optional[StrictStr] = Field(None, description="Relates to Rules/Entitlements. Not supported yet.")
    provisioned_entitlements: Optional[StrictBool] = Field(None, description="Relates to Rules/Entitlements. Not supported yet.")
    __properties = ["id", "label", "user_attribute_mappings", "user_attribute_macros", "attribute_transformations", "skip_if_blank", "values", "default_values", "provisioned_entitlements"]

    """Pydantic configuration"""
    model_config = {
        "validate_by_name": True,
        "validate_by_alias": True,
        "validate_assignment": True
    }

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TokenClaim:
        """Create an instance of TokenClaim from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.model_dump(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TokenClaim:
        """Create an instance of TokenClaim from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TokenClaim.model_validate(obj)

        _obj = TokenClaim.model_validate({
            "id": obj.get("id"),
            "label": obj.get("label"),
            "user_attribute_mappings": obj.get("user_attribute_mappings"),
            "user_attribute_macros": obj.get("user_attribute_macros"),
            "attribute_transformations": obj.get("attribute_transformations"),
            "skip_if_blank": obj.get("skip_if_blank"),
            "values": obj.get("values"),
            "default_values": obj.get("default_values"),
            "provisioned_entitlements": obj.get("provisioned_entitlements")
        })
        return _obj




# coding: utf-8

"""
SAML2 Authentication Module

This module provides compatibility for users expecting to import
OneLogin_Saml2_Auth from onelogin.saml2.auth. However, OneLogin_Saml2_Auth is
actually provided by the 'python3-saml' package, not this onelogin package.

This onelogin package is for OneLogin API management, while python3-saml is
for SAML2 authentication integration.
"""

import os
import site


def _check_python3_saml_installed():
    """Check if python3-saml is installed by looking for its onelogin.saml2.auth module"""
    for site_dir in site.getsitepackages() + [site.getusersitepackages()]:
        if site_dir and os.path.exists(site_dir):
            potential_path = os.path.join(site_dir, 'onelogin', 'saml2', 'auth.py')
            if os.path.exists(potential_path):
                return True
    return False


def __getattr__(name):
    """
    Intercept attempts to import OneLogin_Saml2_Auth and provide helpful
    error message based on whether python3-saml is detected.
    """
    if name == "OneLogin_Saml2_Auth":
        python3_saml_installed = _check_python3_saml_installed()
        
        if python3_saml_installed:
            # python3-saml is installed but there's a namespace conflict
            raise ImportError(
                "OneLogin_Saml2_Auth is not available due to a package namespace conflict.\n\n"
                "You have both 'onelogin' (API management) and 'python3-saml' (SAML authentication) installed.\n"
                "These packages both provide 'onelogin' modules, causing a conflict.\n\n"
                "To fix this conflict:\n\n"
                "OPTION 1 - If you only need SAML authentication:\n"
                "  1. Uninstall this package: pip uninstall onelogin\n"
                "  2. Then import will work: from onelogin.saml2.auth import OneLogin_Saml2_Auth\n\n"
                "OPTION 2 - If you need both packages:\n"
                "  1. Import directly from python3-saml's location in site-packages\n"
                "  2. See: https://github.com/onelogin/python3-saml for documentation\n\n"
                "OPTION 3 - Use virtual environments to separate the packages\n\n"
                "To check your installations: pip list | grep -E '(onelogin|python3-saml)'"
            )
        else:
            # python3-saml is not installed
            raise ImportError(
                "OneLogin_Saml2_Auth is not available in this package.\n\n"
                "This package (onelogin) is for OneLogin API management.\n"
                "For SAML2 authentication, you need the 'python3-saml' package.\n\n"
                "To fix this:\n"
                "1. Install the correct package: pip install python3-saml\n"
                "2. Import from: from onelogin.saml2.auth import OneLogin_Saml2_Auth\n\n"
                "For more information: https://github.com/onelogin/python3-saml"
            )

    raise AttributeError(
        f"module 'onelogin.saml2.auth' has no attribute '{name}'"
    )


# Make module attributes available for inspection
__all__ = []



# coding: utf-8

"""
    OneLogin API Python SDK

    Official Python SDK for the OneLogin API
"""


import re  # noqa: F401

from pydantic import validate_call

from pydantic import StrictInt, StrictStr

from typing import List, Optional

from onelogin.models.auth_id import AuthId
from onelogin.models.auth_scope import AuthScope

from onelogin.api_client import ApiClient
from onelogin.api_response import ApiResponse
from onelogin.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class APIAuthScopesApi(object):
    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def create_scope(self, api_auth_id : StrictStr, content_type : Optional[StrictStr] = None, auth_scope : Optional[AuthScope] = None, **kwargs) -> AuthScope:  # noqa: E501
        """Create Api Auth Server Scope  # noqa: E501

        Create API Auth Server Scope  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_scope(api_auth_id, content_type, auth_scope, async_req=True)
        >>> result = thread.get()

        :param api_auth_id: (required)
        :type api_auth_id: str
        :param content_type:
        :type content_type: str
        :param auth_scope:
        :type auth_scope: AuthScope
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AuthScope
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the create_scope_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.create_scope_with_http_info(api_auth_id, content_type, auth_scope, **kwargs)  # noqa: E501

    @validate_call
    def create_scope_with_http_info(self, api_auth_id : StrictStr, content_type : Optional[StrictStr] = None, auth_scope : Optional[AuthScope] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Create Api Auth Server Scope  # noqa: E501

        Create API Auth Server Scope  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_scope_with_http_info(api_auth_id, content_type, auth_scope, async_req=True)
        >>> result = thread.get()

        :param api_auth_id: (required)
        :type api_auth_id: str
        :param content_type:
        :type content_type: str
        :param auth_scope:
        :type auth_scope: AuthScope
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(AuthScope, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'api_auth_id',
            'content_type',
            'auth_scope'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_scope" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['api_auth_id']:
            _path_params['api_auth_id'] = _params['api_auth_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['content_type']:
            _header_params['Content-Type'] = _params['content_type']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['auth_scope'] is not None:
            _body_params = _params['auth_scope']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['OAuth2']  # noqa: E501

        _response_types_map = {
            '200': "AuthScope",
            '401': "AltErr",
            '404': "AltErr",
            '422': "AltErr",
        }

        return self.api_client.call_api(
            '/api/2/api_authorizations/{api_auth_id}/scopes', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_call
    def delete_scope(self, api_auth_id : StrictStr, scope_id : StrictInt, content_type : Optional[StrictStr] = None, **kwargs) -> None:  # noqa: E501
        """Delete Api Auth Server Scope  # noqa: E501

        Delete Scope  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_scope(api_auth_id, scope_id, content_type, async_req=True)
        >>> result = thread.get()

        :param api_auth_id: (required)
        :type api_auth_id: str
        :param scope_id: (required)
        :type scope_id: int
        :param content_type:
        :type content_type: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the delete_scope_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.delete_scope_with_http_info(api_auth_id, scope_id, content_type, **kwargs)  # noqa: E501

    @validate_call
    def delete_scope_with_http_info(self, api_auth_id : StrictStr, scope_id : StrictInt, content_type : Optional[StrictStr] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Delete Api Auth Server Scope  # noqa: E501

        Delete Scope  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_scope_with_http_info(api_auth_id, scope_id, content_type, async_req=True)
        >>> result = thread.get()

        :param api_auth_id: (required)
        :type api_auth_id: str
        :param scope_id: (required)
        :type scope_id: int
        :param content_type:
        :type content_type: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'api_auth_id',
            'scope_id',
            'content_type'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_scope" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['api_auth_id']:
            _path_params['api_auth_id'] = _params['api_auth_id']

        if _params['scope_id']:
            _path_params['scope_id'] = _params['scope_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['content_type']:
            _header_params['Content-Type'] = _params['content_type']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['OAuth2']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/api/2/api_authorizations/{api_auth_id}/scopes/{scope_id}', 'DELETE',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_call
    def get_scopes(self, api_auth_id : StrictStr, content_type : Optional[StrictStr] = None, **kwargs) -> List[AuthScope]:  # noqa: E501
        """Get Api Auth Server Scopes  # noqa: E501

        List Authorization Scopes  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_scopes(api_auth_id, content_type, async_req=True)
        >>> result = thread.get()

        :param api_auth_id: (required)
        :type api_auth_id: str
        :param content_type:
        :type content_type: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: List[AuthScope]
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_scopes_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_scopes_with_http_info(api_auth_id, content_type, **kwargs)  # noqa: E501

    @validate_call
    def get_scopes_with_http_info(self, api_auth_id : StrictStr, content_type : Optional[StrictStr] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Get Api Auth Server Scopes  # noqa: E501

        List Authorization Scopes  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_scopes_with_http_info(api_auth_id, content_type, async_req=True)
        >>> result = thread.get()

        :param api_auth_id: (required)
        :type api_auth_id: str
        :param content_type:
        :type content_type: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(List[AuthScope], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'api_auth_id',
            'content_type'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_scopes" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['api_auth_id']:
            _path_params['api_auth_id'] = _params['api_auth_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['content_type']:
            _header_params['Content-Type'] = _params['content_type']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['OAuth2']  # noqa: E501

        _response_types_map = {
            '200': "List[AuthScope]",
            '401': "AltErr",
        }

        return self.api_client.call_api(
            '/api/2/api_authorizations/{api_auth_id}/scopes', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_call
    def update_scope(self, api_auth_id : StrictStr, scope_id : StrictInt, content_type : Optional[StrictStr] = None, auth_scope : Optional[AuthScope] = None, **kwargs) -> AuthId:  # noqa: E501
        """Update Api Auth Server Scope  # noqa: E501

        Update Scope  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_scope(api_auth_id, scope_id, content_type, auth_scope, async_req=True)
        >>> result = thread.get()

        :param api_auth_id: (required)
        :type api_auth_id: str
        :param scope_id: (required)
        :type scope_id: int
        :param content_type:
        :type content_type: str
        :param auth_scope:
        :type auth_scope: AuthScope
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AuthId
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the update_scope_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.update_scope_with_http_info(api_auth_id, scope_id, content_type, auth_scope, **kwargs)  # noqa: E501

    @validate_call
    def update_scope_with_http_info(self, api_auth_id : StrictStr, scope_id : StrictInt, content_type : Optional[StrictStr] = None, auth_scope : Optional[AuthScope] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Update Api Auth Server Scope  # noqa: E501

        Update Scope  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_scope_with_http_info(api_auth_id, scope_id, content_type, auth_scope, async_req=True)
        >>> result = thread.get()

        :param api_auth_id: (required)
        :type api_auth_id: str
        :param scope_id: (required)
        :type scope_id: int
        :param content_type:
        :type content_type: str
        :param auth_scope:
        :type auth_scope: AuthScope
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(AuthId, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'api_auth_id',
            'scope_id',
            'content_type',
            'auth_scope'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_scope" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['api_auth_id']:
            _path_params['api_auth_id'] = _params['api_auth_id']

        if _params['scope_id']:
            _path_params['scope_id'] = _params['scope_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['content_type']:
            _header_params['Content-Type'] = _params['content_type']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['auth_scope'] is not None:
            _body_params = _params['auth_scope']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['OAuth2']  # noqa: E501

        _response_types_map = {
            '200': "AuthId",
            '401': "AltErr",
            '404': "AltErr",
            '422': "AltErr",
        }

        return self.api_client.call_api(
            '/api/2/api_authorizations/{api_auth_id}/scopes/{scope_id}', 'PUT',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    OneLogin API Python SDK

    Official Python SDK for the OneLogin API
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr

class GetAuthenticationDevices200ResponseInner(BaseModel):
    """
    GetAuthenticationDevices200ResponseInner
    """
    device_id: Optional[StrictStr] = Field(None, description="MFA device identifier.")
    user_display_name: Optional[StrictStr] = Field(None, description="Authentication factor display name assigned by users when they register the device.")
    type_display_name: Optional[StrictStr] = Field(None, description="Authentication factor display name as it appears to users upon initial registration, as defined by admins at Settings > Authentication Factors.")
    auth_factor_name: Optional[StrictStr] = Field(None, description="Authentication factor name, as it appears to administrators in OneLogin.")
    default: Optional[StrictBool] = Field(False, description="true = is user’s default MFA device for OneLogin.")
    __properties = ["device_id", "user_display_name", "type_display_name", "auth_factor_name", "default"]

    """Pydantic configuration"""
    model_config = {
        "validate_by_name": True,
        "validate_by_alias": True,
        "validate_assignment": True
    }

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GetAuthenticationDevices200ResponseInner:
        """Create an instance of GetAuthenticationDevices200ResponseInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.model_dump(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GetAuthenticationDevices200ResponseInner:
        """Create an instance of GetAuthenticationDevices200ResponseInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return GetAuthenticationDevices200ResponseInner.model_validate(obj)

        _obj = GetAuthenticationDevices200ResponseInner.model_validate({
            "device_id": obj.get("device_id"),
            "user_display_name": obj.get("user_display_name"),
            "type_display_name": obj.get("type_display_name"),
            "auth_factor_name": obj.get("auth_factor_name"),
            "default": obj.get("default") if obj.get("default") is not None else False
        })
        return _obj




# coding: utf-8

"""
    OneLogin API Python SDK

    Official Python SDK for the OneLogin API
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class SendInviteLinkRequest(BaseModel):
    """
    SendInviteLinkRequest
    """
    email: Optional[StrictStr] = Field(None, description="Set to the user email address to generate an invite link. The value is case sensitive.")
    personal_email: Optional[StrictStr] = Field(None, description="To send an invite email to a different address than the one provided in email, provide it here. The invite link is sent to this address instead.")
    __properties = ["email", "personal_email"]

    """Pydantic configuration"""
    model_config = {
        "validate_by_name": True,
        "validate_by_alias": True,
        "validate_assignment": True
    }

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SendInviteLinkRequest:
        """Create an instance of SendInviteLinkRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.model_dump(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SendInviteLinkRequest:
        """Create an instance of SendInviteLinkRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SendInviteLinkRequest.model_validate(obj)

        _obj = SendInviteLinkRequest.model_validate({
            "email": obj.get("email"),
            "personal_email": obj.get("personal_email")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API Python SDK

    Official Python SDK for the OneLogin API
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, conlist
from onelogin.models.get_mfa_factors200_response_data_auth_factors_inner import GetMFAFactors200ResponseDataAuthFactorsInner

class GetMFAFactors200ResponseData(BaseModel):
    """
    GetMFAFactors200ResponseData
    """
    auth_factors: Optional[conlist(GetMFAFactors200ResponseDataAuthFactorsInner)] = None
    __properties = ["auth_factors"]

    """Pydantic configuration"""
    model_config = {
        "validate_by_name": True,
        "validate_by_alias": True,
        "validate_assignment": True
    }

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GetMFAFactors200ResponseData:
        """Create an instance of GetMFAFactors200ResponseData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.model_dump(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in auth_factors (list)
        _items = []
        if self.auth_factors:
            for _item in self.auth_factors:
                if _item:
                    _items.append(_item.to_dict())
            _dict['auth_factors'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GetMFAFactors200ResponseData:
        """Create an instance of GetMFAFactors200ResponseData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return GetMFAFactors200ResponseData.model_validate(obj)

        _obj = GetMFAFactors200ResponseData.model_validate({
            "auth_factors": [GetMFAFactors200ResponseDataAuthFactorsInner.from_dict(_item) for _item in obj.get("auth_factors")] if obj.get("auth_factors") is not None else None
        })
        return _obj




# coding: utf-8

"""
    OneLogin API Python SDK

    Official Python SDK for the OneLogin API
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr
from onelogin.models.sso_saml_certificate import SsoSamlCertificate

class SsoSaml(BaseModel):
    """
    SsoSaml
    """
    metadata_url: Optional[StrictStr] = None
    acs_url: Optional[StrictStr] = None
    sls_url: Optional[StrictStr] = None
    issuer: Optional[StrictStr] = None
    certificate: Optional[SsoSamlCertificate] = None
    __properties = ["metadata_url", "acs_url", "sls_url", "issuer", "certificate"]

    """Pydantic configuration"""
    model_config = {
        "validate_by_name": True,
        "validate_by_alias": True,
        "validate_assignment": True
    }

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SsoSaml:
        """Create an instance of SsoSaml from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.model_dump(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of certificate
        if self.certificate:
            _dict['certificate'] = self.certificate.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SsoSaml:
        """Create an instance of SsoSaml from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SsoSaml.model_validate(obj)

        _obj = SsoSaml.model_validate({
            "metadata_url": obj.get("metadata_url"),
            "acs_url": obj.get("acs_url"),
            "sls_url": obj.get("sls_url"),
            "issuer": obj.get("issuer"),
            "certificate": SsoSamlCertificate.from_dict(obj.get("certificate")) if obj.get("certificate") is not None else None
        })
        return _obj

